@@ -30,4 +30,9 @@ done
 
 lipo -create -output "Lite XL.app/Contents/MacOS/lite-xl" "$WORKDIR/"*-lite-xl
 
+# https://eclecticlight.co/2019/01/17/code-signing-for-the-concerned-3-signing-an-app/
+# https://wiki.lazarus.freepascal.org/Code_Signing_for_macOS#Big_Sur_and_later_on_Apple_M1_ARM64_processors
+# codesign all the files again, hopefully this would fix signature validation
+codesign --force --deep --digest-algorithm=sha1,sha256 -s - "Lite XL.app"
+
 source scripts/appdmg.sh "$2"
\ No newline at end of file
